@@ -43,9 +43,9 @@ def get_clang_style_string():
         AlwaysBreakTemplateDeclarations: Yes,
         BinPackArguments: false,
         BinPackParameters: false,
-        AllowShortFunctionsOnASingleLine: Empty,
+        AllowShortFunctionsOnASingleLine: false,
         BreakBeforeBraces: Custom,
-        BraceWrapping: { AfterEnum: true, AfterStruct: true }
+        BraceWrapping: { AfterEnum: false, AfterStruct: false }
     }"""
 
 
